@@ -85,14 +85,18 @@ class FlateDecode:
         """
         Decode data which is flate-encoded.
 
-        :param data: flate-encoded data.
-        :param decode_parms: a dictionary of values, understanding the
+        Args:
+          data: flate-encoded data.
+          decode_parms: a dictionary of values, understanding the
             "/Predictor":<int> key only
-        :return: the flate-decoded data.
 
-        :raises PdfReadError:
+        Returns:
+          The flate-decoded data.
+
+        Raises:
+          PdfReadError:
         """
-        if "decodeParms" in kwargs:  # pragma: no cover
+        if "decodeParms" in kwargs:  # deprecated
             deprecate_with_replacement("decodeParms", "parameters", "4.0.0")
             decode_parms = kwargs["decodeParms"]
         str_data = decompress(data)
@@ -202,15 +206,22 @@ class ASCIIHexDecode:
         **kwargs: Any,
     ) -> str:
         """
-        :param data: a str sequence of hexadecimal-encoded values to be
+        Decode an ASCII-Hex encoded data stream.
+
+        Args:
+          data: a str sequence of hexadecimal-encoded values to be
             converted into a base-7 ASCII string
-        :param decode_parms:
-        :return: a string conversion in base-7 ASCII, where each of its values
+          decode_parms: a string conversion in base-7 ASCII, where each of its values
             v is such that 0 <= ord(v) <= 127.
 
-        :raises PdfStreamError:
+        Returns:
+          A string conversion in base-7 ASCII, where each of its values
+          v is such that 0 <= ord(v) <= 127.
+
+        Raises:
+          PdfStreamError:
         """
-        if "decodeParms" in kwargs:  # pragma: no cover
+        if "decodeParms" in kwargs:  # deprecated
             deprecate_with_replacement("decodeParms", "parameters", "4.0.0")
             decode_parms = kwargs["decodeParms"]  # noqa: F841
         retval = ""
@@ -284,7 +295,8 @@ class LZWDecode:
             http://www.rasip.fer.hr/research/compress/algorithms/fund/lz/lzw.html
             and the PDFReference
 
-            :raises PdfReadError: If the stop code is missing
+            Raises:
+              PdfReadError: If the stop code is missing
             """
             cW = self.CLEARDICT
             baos = ""
@@ -324,11 +336,16 @@ class LZWDecode:
         **kwargs: Any,
     ) -> str:
         """
-        :param data: ``bytes`` or ``str`` text to decode.
-        :param decode_parms: a dictionary of parameter values.
-        :return: decoded data.
+        Decode an LZW encoded data stream.
+
+        Args:
+          data: bytes`` or ``str`` text to decode.
+          decode_parms: a dictionary of parameter values.
+
+        Returns:
+          decoded data.
         """
-        if "decodeParms" in kwargs:  # pragma: no cover
+        if "decodeParms" in kwargs:  # deprecated
             deprecate_with_replacement("decodeParms", "parameters", "4.0.0")
             decode_parms = kwargs["decodeParms"]  # noqa: F841
         return LZWDecode.Decoder(data).decode()
@@ -343,7 +360,7 @@ class ASCII85Decode:
         decode_parms: Union[None, ArrayObject, DictionaryObject] = None,
         **kwargs: Any,
     ) -> bytes:
-        if "decodeParms" in kwargs:  # pragma: no cover
+        if "decodeParms" in kwargs:  # deprecated
             deprecate_with_replacement("decodeParms", "parameters", "4.0.0")
             decode_parms = kwargs["decodeParms"]  # noqa: F841
         if isinstance(data, str):
@@ -376,7 +393,7 @@ class DCTDecode:
         decode_parms: Union[None, ArrayObject, DictionaryObject] = None,
         **kwargs: Any,
     ) -> bytes:
-        if "decodeParms" in kwargs:  # pragma: no cover
+        if "decodeParms" in kwargs:  # deprecated
             deprecate_with_replacement("decodeParms", "parameters", "4.0.0")
             decode_parms = kwargs["decodeParms"]  # noqa: F841
         return data
@@ -389,7 +406,7 @@ class JPXDecode:
         decode_parms: Union[None, ArrayObject, DictionaryObject] = None,
         **kwargs: Any,
     ) -> bytes:
-        if "decodeParms" in kwargs:  # pragma: no cover
+        if "decodeParms" in kwargs:  # deprecated
             deprecate_with_replacement("decodeParms", "parameters", "4.0.0")
             decode_parms = kwargs["decodeParms"]  # noqa: F841
         return data
@@ -457,7 +474,7 @@ class CCITTFaxDecode:
         height: int = 0,
         **kwargs: Any,
     ) -> bytes:
-        if "decodeParms" in kwargs:  # pragma: no cover
+        if "decodeParms" in kwargs:  # deprecated
             deprecate_with_replacement("decodeParms", "parameters", "4.0.0")
             decode_parms = kwargs["decodeParms"]
         parms = CCITTFaxDecode._get_parameters(decode_parms, height)
@@ -550,7 +567,7 @@ def decode_stream_data(stream: Any) -> Union[str, bytes]:  # utils.StreamObject
     return data
 
 
-def decodeStreamData(stream: Any) -> Union[str, bytes]:  # pragma: no cover
+def decodeStreamData(stream: Any) -> Union[str, bytes]:  # deprecated
     deprecate_with_replacement("decodeStreamData", "decode_stream_data", "4.0.0")
     return decode_stream_data(stream)
 
@@ -562,7 +579,11 @@ def _xobj_to_image(x_object_obj: Dict[str, Any]) -> Tuple[Optional[str], bytes]:
     It's unclear if pypdf will keep this function here, hence it's private.
     It might get removed at any point.
 
-    :return: Tuple[file extension, bytes]
+    Args:
+      x_object_obj:
+
+    Returns:
+        Tuple[file extension, bytes]
     """
     try:
         from PIL import Image
